@@ -2,37 +2,86 @@ package Perl::Dist::Bootstrap;
 
 use 5.006;
 use strict;
-use warnings;
-use base 'Perl::Dist::Vanilla';
+use base 'Perl::Dist';
 use File::Remove ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.90_03';
+	$VERSION = '0.50';
 }
 
 
 
 
 
+#####################################################################
+# Configuration
+
+sub app_name             { 'Bootstrap Perl'              }
+sub app_ver_name         { 'Bootstrap Perl Beta 1'       }
+sub app_publisher        { 'Vanilla Perl Project'        }
+sub app_publisher_url    { 'http://vanillaperl.com/'     }
+sub app_id               { 'bootstrapperl'               }
+sub output_base_filename { 'bootstrap-perl-5.8.8-beta-1' }
+
+
+
+
+
 #####################################################################
 # Constructor
 
 # Apply some default paths
 sub new {
-	shift->SUPER::new(
-		perl_version         => '588',
-		app_name             => 'Bootstrap Perl',
-		app_ver_name         => 'Bootstrap Perl Beta 2',
-		output_base_filename => 'bootstrap-perl-5.8.8-beta-2',
-		image_dir            => 'C:\\bootperl',
+	my $class = shift;
+	return $class->SUPER::new(
+		image_dir => 'C:\\bootperl',
+		temp_dir  => 'C:\\tmp\\bp',
 		@_,
 	);
 }
 
-sub install_perl {
+sub run {
 	my $self = shift;
-	$self->SUPER::install_perl(@_);
+
+	# Install the main binaries
+	my $t1 = time;
+	$self->install_c_toolchain;
+	my $d1 = time - $t1;
+	$self->trace("Completed install_binaries in $d1 seconds\n");
+
+	# Install the additional C libs
+	my $t6 = time;
+	$self->install_c_libraries;
+	my $d6 = time - $t6;
+	$self->trace("Completed install_libraries in $d6 seconds\n");
+
+	# Install Perl 5.8.8
+	my $t2 = time;
+	$self->install_perl_588;
+	my $d2 = time - $t2;
+	$self->trace("Completed install_perl_588 in $d2 seconds\n");
+
+	# Install the additional modules
+	my $t4 = time;
+	$self->install_perl_modules;
+	my $d4 = time - $t4;
+	$self->trace("Completed install_modules in $d4 seconds\n");
+
+	# Write out the zip
+	my $t5  = time;
+	$self->remove_waste;
+	my $exe = $self->write_exe;
+	my $d5  = time - $t5;
+	$self->trace("Completed write in $d5 seconds\n");
+	$self->trace("Distribution exe file created as $exe\n");
+
+	return 1;
+}
+
+sub install_perl_588 {
+	my $self = shift;
+	$self->SUPER::install_perl_588(@_);
 
 	# Install the bootperl CPAN::Config
 	$self->install_file(
@@ -43,11 +92,19 @@ sub install_perl {
 	return 1;
 }
 
-# Install various additional modules
 sub install_perl_modules {
 	my $self = shift;
 
+	# Install the companion Perl modules for the
+	# various libs we installed.
+	$self->install_module(
+		name => 'XML::LibXML',
+	);
+
 	# Install the basics
+	$self->install_module(
+		name => 'Params::Util',
+	);
 	$self->install_module(
 		name => 'Bundle::LWP',
 	);
@@ -59,6 +116,9 @@ sub install_perl_modules {
 	$self->install_module(
 		name => 'pler',
 	);
+	$self->install_module(
+		name => 'pip',
+	);
 	$self->install_module(
 		name => 'PAR::Dist',
 	);
@@ -93,16 +153,14 @@ Perl::Dist::Bootstrap - A bootstrap Perl for building Perl distributions
 "Bootstrap Perl" is a Perl distribution, and a member of the
 "Vanilla Perl" series of distributions.
 
-The L<Perl::Dist::Bootstrap> module can be used in conjunction wit the
-L<perldist> command line tool to create a bootstrap Perl distribution.
+The Perl::Dist::Bootstrap module can be used to create a bootstrap
+Perl distribution.
 
 Most of the time nobody will be using
 Perl::Dist::Bootstrap directly, but will be downloading the pre-built
 installer for Bootstrap Perl from the Vanilla Perl website at
 L<http://vanillaperl.com/>.
 
-=head2 Why Is This Needed?
-
 For people building Win32 Perl distributions based on L<Perl::Dist>,
 one gotcha is that the distributions have hard-coded install paths.
 
@@ -120,26 +178,30 @@ Perl distribution creation process.
 
 =head2 CONFIGURATION
 
-Bootstrap Perl must be installed in C:\bootstrap.  The
+Bootstrap Perl must be installed in C:\strawberry-perl.  The
 executable installer adds the following environment variable changes:
 
     * adds directories to PATH
-        - C:\bootstrap\perl\bin
-        - C:\bootstrap\c\bin
+        - C:\strawberry-perl\perl\bin
+        - C:\strawberry-perl\dmake\bin
+        - C:\strawberry-perl\c
+        - C:\strawberry-perl\c\bin
 
     * adds directories to LIB
-        - C:\bootstrap\c\lib
-        - C:\bootstrap\perl\bin
+        - C:\strawberry-perl\c\lib
+        - C:\strawberry-perl\perl\bin
 
     * adds directories to INCLUDE 
-        - C:\bootstrap\c\include
-        - C:\bootstrap\perl\lib\CORE
+        - C:\strawberry-perl\c\include
+        - C:\strawberry-perl\perl\lib\CORE
+        - C:\strawberry-perl\perl\lib\encode
 
 LIB and INCLUDE changes are likely more than are necessary, but attempt to
 head off potential problems compiling external programs for use with Perl.
 
-The "cpan" program is pre-configured with a known-good setup, but you may
-wish to reconfigure it.
+The first time that the "cpan" program is run, users will be prompted for
+configuration settings.  With the defaults provided in Strawberry Perl, users
+may answer "no" to manual configuration and the installation should still work.
 
 Manual CPAN configuration may be repeated by running the following command:
 
@@ -147,7 +209,7 @@ Manual CPAN configuration may be repeated by running the following command:
 
 =head1 SUPPORT
 
-Bootstrap Perl discussion is centered at L<http://win32.perl.org/>.
+Vanilla Perl discussion is centered at L<http://win32.perl.org/>.
 
 Other venues for discussion may be listed there.
 
@@ -162,7 +224,7 @@ Adam Kennedy <adamk@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2007 - 2008 Adam Kennedy.
+Copyright 2007 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
