@@ -1,30 +1,30 @@
 package Perl::Dist::Inno::Script;
 
-use 5.006;
 use strict;
-use warnings;
-use Carp                       qw{ croak };
+use Carp                       qw{ croak   };
 use File::Spec                 ();
 use File::Temp                 ();
 use IPC::Run3                  ();
-use Params::Util               qw{ _STRING _IDENTIFIER };
+use Params::Util               qw{ _STRING };
 use Perl::Dist::Inno::File     ();
 use Perl::Dist::Inno::Icon     ();
 use Perl::Dist::Inno::Registry ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.90_03';
+	$VERSION = '0.50';
 }
 
 use Object::Tiny qw{
-	app_id
 	app_name
+	app_ver_name
 	app_publisher
 	app_publisher_url
+	app_id
 	default_group_name
 	default_dir_name
 	output_dir
+	output_base_filename
 	source_dir
 	bin_compil32
 };
@@ -42,10 +42,7 @@ sub new {
 		$self->{default_group_name} = $self->app_name;
 	}
 
-	# Check and default params
-	unless ( _IDENTIFIER($self->app_id) ) {
-		croak("Missing or invalid app_id param");
-	}
+	# Check params
 	unless ( _STRING($self->app_name) ) {
 		croak("Missing or invalid app_name param");
 	}
@@ -58,6 +55,9 @@ sub new {
 	unless ( _STRING($self->app_publisher_url) ) {
 		croak("Missing or invalid app_publisher_uri param");
 	}
+	unless ( _STRING($self->app_id) ) {
+		croak("Missing or invalid app_id param");
+	}
 	unless ( _STRING($self->default_group_name) ) {
 		croak("Missing or invalid default_group_name param");
 	}
@@ -68,7 +68,7 @@ sub new {
 		croak("Missing or invalid output_dir param");
 	}
 	unless ( -d $self->output_dir ) {
-		croak("The output_dir " . $self->output_dir . "directory does not exist");
+		croak("The output_dir directory does not exist");
 	}
 	unless ( -w $self->output_dir ) {
 		croak("The output_dir directory is not writable");
@@ -102,24 +102,6 @@ sub new {
 	return $self;
 }
 
-# Default the versioned name to an unversioned name
-sub app_ver_name {
-	$_[0]->{app_ver_name} or
-	$_[0]->app_name;
-}
-
-# Default the output filename to the id plus the current date
-sub output_base_filename {
-	$_[0]->{output_base_filename} or
-	$_[0]->app_id . '-' . $_[0]->output_date_string;
-}
-
-# Convenience method
-sub output_date_string {
-	my @t = scalar localtime;
-	return sprintf( "%04d%02d%02d", $t[5] + 1900, $t[4] + 1, $t[3] );
-}
-
 sub files {
 	return @{ $_[0]->{files} };
 }
@@ -186,8 +168,8 @@ sub add_dir {
 	my $self = shift;
 	my $name = shift;
 	$self->add_file(
-		source             => "$name\\*",
-		dest_dir           => "{app}\\$name",
+		source   => "$name\\*",
+		dest_dir => "{app}\\$name",
 		recurse_subdirs    => 1,
 		create_all_subdirs => 1,
 	);
@@ -211,6 +193,17 @@ sub add_uninstall {
 	return 1;
 }
 
+sub add_url {
+	my $self = shift;
+	my $name = shift;
+	my $url  = shift;
+	$self->add_icon(
+		name     => '',
+		filename =>
+	);
+	return 1;
+}
+
 sub add_registry {
 	my $self     = shift;
 	my $registry = Perl::Dist::Inno::Registry->new(@_);
@@ -261,7 +254,6 @@ sub as_string {
 		'; Where the output goes',
 		'OutputDir='          . $self->output_dir,
 		'OutputBaseFilename=' . $self->output_base_filename,
-		'UsePreviousAppDir='  . 'no',
 		'',
 		'; Source location',
 		'SourceDir='          . $self->source_dir,
@@ -274,10 +266,6 @@ sub as_string {
 		'SolidCompression='   . 'yes',
 		'ChangesEnvironment=' . 'yes',
 		'',
-		'; Delete old install',
-		'[InstallDelete]',
-		'Type: filesandordirs; Name: "' . $self->source_dir . '"',
-		'',
 	);
 
 	# Start with only English for now
