@@ -1,33 +1,12 @@
 package Perl::Dist::Vanilla;
 
-use 5.006;
+use 5.005;
 use strict;
-use warnings;
 use base 'Perl::Dist';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '15';
-}
-
-
-
-
-
-#####################################################################
-# Upstream Binary Packages
-
-my %PACKAGES = (
-	# Disabled as the generate test failures in 5.10.0
-	# 'mingw-runtime' => 'mingw-runtime-3.14.tar.gz',
-	# 'w32api'        => 'w32api-3.11.tar.gz',
-	'dmake'         => 'dmake-4.11-20080107-SHAY.zip',
-	'expat'         => 'expat-2.0.1-vanilla.zip',
-);
-
-sub binary_file {
-	$PACKAGES{$_[1]} or
-	shift->SUPER::binary_file(@_);
+	$VERSION = '12';
 }
 
 
@@ -37,33 +16,20 @@ sub binary_file {
 #####################################################################
 # Configuration
 
+sub app_name             { 'Vanilla Perl'                       }
+sub app_ver_name         { "Vanilla Perl 5.10.0 $VERSION"       }
+sub app_publisher        { 'Vanilla Perl Project'               }
+sub app_publisher_url    { 'http://vanillaperl.org/'            }
+sub app_id               { 'vanillaperl'                        }
+sub output_base_filename { "vanilla-perl-5.10.0-build-$VERSION" }
+
 # Apply some default paths
 sub new {
-	my $class = shift;
-
-	# Prepend defaults
-	my $self = $class->SUPER::new(
-		app_id            => 'vanillaperl',
-		app_name          => 'Vanilla Perl',
-		app_publisher     => 'Vanilla Perl Project',
-		app_publisher_url => 'http://vanillaperl.org/',
-		image_dir         => 'C:\\vanilla',
+	shift->SUPER::new(
+		image_dir => 'C:\\vanilla',
+		temp_dir  => 'C:\\tmp\\vp',
 		@_,
 	);
-
-	return $self;
-}
-
-# Lazily default the full name
-sub app_ver_name {
-	$_[0]->{app_ver_name} or
-	$_[0]->app_name . ' ' . $_[0]->perl_version_human . ' ' . $_[0]->VERSION;
-}
-
-# Lazily default the file name
-sub output_base_filename {
-	$_[0]->{output_base_filename} or
-	'vanilla-perl-' . $_[0]->perl_version_human . '-build-' . $_[0]->VERSION;
 }
 
 
@@ -73,42 +39,37 @@ sub output_base_filename {
 #####################################################################
 # Installation Script
 
-sub install_c_libraries {
+# Vanilla never has any additional libraries.
+# Just install the C toolchain and Perl core.
+sub run {
 	my $self = shift;
-	$self->SUPER::install_c_libraries(@_);
 
+	# Install the C toolchain
+	my $t1 = time;
+	$self->install_c_toolchain;
+	$self->trace("Completed install_c_toolchain in " . (time - $t1) . " seconds\n");
+
+	# Install the Perl 5.10.0 binary
+	my $t2 = time;
+	$self->install_perl_5100;
+	$self->trace("Complete install_perl_5110 in " . (time - $t2) . " seconds\n");
+
+	# Write out the zip
+	my $t3  = time;
+	$self->remove_waste;
+	my $exe = $self->write_exe;
+	$self->trace("Completed write_exe in " . (time - $t3) . " seconds\n");
+
+	# Finished
+	$self->trace("Distribution exe file created as $exe\n");
 	return 1;
 }
 
-sub install_expat {
+sub install_perl_5110 {
 	my $self = shift;
+	$self->SUPER::install_perl(@_);
 
-	#$self->install_binary(
-	#	name => 'expat',
-	#);
-
-	# Install the PAR version of libexpat
-	$self->install_par(
-		name  => 'libexpat',
-		share => 'Perl-Dist vanilla/libexpat-vanilla.par',
-	);
-
-	return 1;
-}
-
-sub install_perl_5100_bin {
-	my $self  = shift;
-	$self->SUPER::install_perl_5100_bin(@_);
-
-	# Overwrite the CPAN config to be relocatable
-	$self->install_file(
-		share      => 'Perl-Dist vanilla/Config5100.pm',
-		install_to => 'perl/lib/Config.pm',
-	);
-	$self->install_file(
-		share      => 'Perl-Dist vanilla/Config_heavy5100.pl',
-		install_to => 'perl/lib/Config_heavy.pl',
-	);
+	# Install the vanilla CPAN::Config
 	$self->install_file(
 		share      => 'Perl-Dist vanilla/CPAN_Config.pm',
 		install_to => 'perl/lib/CPAN/Config.pm',
@@ -117,46 +78,13 @@ sub install_perl_5100_bin {
 	return 1;
 }
 
-sub install_perl_modules {
-	my $self = shift;
-	$self->SUPER::install_perl_modules(@_);
-
-	$self->install_module(
-		name  => 'Win32::File',
-		force => 1,
-	);
-	$self->install_module(
-		name => 'Win32::API',
-	);
-
-	# We want expat as well
-	$self->install_expat;
-
-	# Install XML::Parser
-	$self->install_distribution(
-		name             => 'MSERGEANT/XML-Parser-2.36.tar.gz',
-		makefilepl_param => [
-			'EXPATLIBPATH=' . File::Spec->catdir(
-				$self->image_dir, 'c', 'lib',
-			),
-			'EXPATINCPATH=' . File::Spec->catdir(
-				$self->image_dir, 'c', 'include',
-			),
-		],
-	);
-
-	return 1;
-}
-
 1;
 
 __END__
 
-=pod
-
 =head1 NAME
 
-Perl::Dist::Vanilla - Vanilla Perl for Win32
+Perl::Dist::Vanilla - Vanilla Perl for win32
 
 =head1 DESCRIPTION
 
@@ -190,12 +118,12 @@ Perl developers.  The primary anticipated uses for Vanilla Perl include
 examining Win32-related issues in the Perl core, and for working on fixing
 complex dependency and Win32 platform bugs in CPAN modules.  
 
-Vanilla Perl serves as the basis more user-centric Win32 Perl distributions
-that include incremental bundled capabilities for general application
-development or application deployment needs.
+Vanilla Perl will eventually serve as the basis for additional Win32 Perl
+distributions that include incremental bundled capabilities for general
+application development or application deployment needs.
 
-Vanilla Perl is strongly not recommended for general use on Win32 platforms
-for any purpose other than detecting and fixing bugs in Vanilla Perl
+Vanilla Perl is strongly not recommended for general use on Win32 platforms at
+this time for any purpose other than detecting and fixing bugs in Vanilla Perl
 and testing Win32 compatibility of various CPAN modules.
 
 Vanilla Perl will undergo changes without notice over time in an attempt to
@@ -203,10 +131,15 @@ intentionally provoke errors and uncover problems close to the Perl core, so
 users should expect that it may unexpectedly display strange behaviours and
 various other problems.
 
+The Perl::Dist::Vanilla distribution on CPAN contains scripts and instructions
+for downloading component sources and assembling them into the executable
+installer for Vanilla Perl.  It B<does not> include the resulting Vanilla Perl
+installation itself.  
+
 See L</"DOWNLOADING THE INSTALLER"> for instructions on where to download and
 how to install Vanilla Perl.  
 
-See L<Perl::Dist::Inno> at L<http://search.cpan.org> for details on 
+See L<Perl::Dist::Build> at L<http://search.cpan.org> for details on 
 the builder used to create Vanilla Perl from source.
 
 =head1 CHANGES FROM CORE PERL
@@ -217,8 +150,8 @@ of Perl, currently version 5.10.0.
 For the 5.10.0 series, no additional modules are installed.
 
 A stub CPAN Config.pm file is installed.  It provides defaults to the path
-for dmake, to automatically follow dependencies and some other tweaks to
-allow for a smoother CPAN usage.
+for dmake, to automatically follow dependencies and to use the Windows
+temporary directory for the CPAN working directory.
 
 =head1 DOWNLOADING THE INSTALLER
 
@@ -238,12 +171,13 @@ Sorry :(
 
 Vanilla cannot co-exist with any other Perl installations at this time.
 
-Vanilla cannot co-exist with Cygwin.
-
 You should remove any other Perl installations before installing Vanilla Perl.
 
 Vanilla Perl must be installed in C:\vanilla.
 
+Vanilla Perl 5.10.0 Build 9 comes in .zip format. Availability of an
+.exe installer has regressed while .exe creation undergoes a rewrite.
+
 Once installed, you should add to the following environment variables.
 
     * add directories to PATH
@@ -262,8 +196,9 @@ LIB and INCLUDE changes are likely more than are necessary, but attempt to
 head off potential problems compiling external programs for use with Perl
 and various CPAN modules.
 
-The "cpan" program is pre-configured with a known-good setup, but you may
-wish to reconfigure it.
+The first time that the "cpan" program is run, users will be prompted for
+configuration settings. You can go with the defaults if you wish, although
+since Vanilla is for experts only, you should probably configure manually.
 
 Manual CPAN configuration may be repeated by running the following command:
 
@@ -271,8 +206,8 @@ Manual CPAN configuration may be repeated by running the following command:
 
 =head1 CONTACTS AND BUGS REPORTING
 
-Currently, Vanilla Perl discussion is centered at L<http://win32.perl.org>.
-New venues for discussion may be listed there.
+Currently, Vanilla Perl discussion is centered at win32.perl.org.  New 
+venues for discussion may be listed there.
 
 Please report bugs or feature requests using the CPAN Request Tracker.
 Bugs can be sent by email to C<<< bug-Perl-Dist-Vanilla@rt.cpan.org >>> or
